# arpes.laser module

Small utilities for estimating quantities of practical interest when
using a laser for photoemission.

**arpes.laser.electrons\_per\_pulse(photocurrent, division\_ratio=None,
pulse\_rate=None)**
